@@ -1,6 +1,6 @@
 package App::JobLog::Log;
 BEGIN {
-  $App::JobLog::Log::VERSION = '1.002';
+  $App::JobLog::Log::VERSION = '1.003';
 }
 
 # ABSTRACT: the code that lets us interact with the log
@@ -73,9 +73,11 @@ sub all_events {
 sub validate {
     my ($self) = @_;
     my ( $i, $previous_event ) = (0);
+    my $errors = 0;
     while ( my $line = $self->[IO][$i] ) {
         my $ll = App::JobLog::Log::Line->parse($line);
         if ( $ll->is_malformed ) {
+            $errors++;
             print STDERR "line $i -- '$line' -- is malformed; commenting out\n";
             splice @{ $self->[IO] }, $i, 0,
               App::JobLog::Log::Line->new( comment => 'ERROR; malformed line' );
@@ -85,6 +87,7 @@ sub validate {
             if ($previous_event) {
                 if ( DateTime->compare( $previous_event->time, $ll->time ) > 0 )
                 {
+                    $errors++;
                     print STDERR
 "line $i -- '$line' -- is out of order relative to the last event; commenting out\n";
                     splice @{ $self->[IO] }, $i, 0,
@@ -93,6 +96,7 @@ sub validate {
                     $self->[IO][ ++$i ] = $ll->comment_out;
                 }
                 elsif ( $previous_event->is_end && $ll->is_end ) {
+                    $errors++;
                     print STDERR
 "line $i -- '$line' -- specifies the end of a task not yet begun; commenting out\n";
                     splice @{ $self->[IO] }, $i, 0,
@@ -105,6 +109,7 @@ sub validate {
                 }
             }
             elsif ( $ll->is_end ) {
+                $errors++;
                 print STDERR
 "line $i -- '$line' -- specifies the end of a task not yet begun; commenting out\n";
                 splice @{ $self->[IO] }, $i, 0,
@@ -118,6 +123,7 @@ sub validate {
         }
         $i++;
     }
+    return $errors;
 }
 
 
@@ -262,11 +268,14 @@ sub find_previous {
     # if the log is empty, return empty list
     return () unless $start_event && $end_event;
 
-# if the start time (improbably but fortuitously) happens to be what we're looking
-# for, return it
+    # if the start time (improbably but fortuitously) happens to be what we're
+    # looking for, return it
     return ( $start_event, $top )
       if DateTime->compare( $start_event->start, $e ) == 0;
 
+    # likewise for the end time
+    return ( $end_event, $bottom ) if $end_event->start < $e;
+
     # return the empty list if the event in question precede the first
     # event in the log
     return () unless $start_event->start < $e;
@@ -360,17 +369,12 @@ sub _scan_for_previous {
         my $line = $io->[$index];
         my $ll   = App::JobLog::Log::Line->parse($line);
         if ( $ll->is_event ) {
-            if ($previous) {
-                $previous->end = $ll->time if $previous->is_open;
-                last if $ll->time > $e;
-            }
+            $previous->end = $ll->time if $previous && $previous->is_open;
+            last if $ll->time > $e;
             if ( $ll->is_beginning ) {
                 $previous       = App::JobLog::Log::Event->new($ll);
                 $previous_index = $index;
             }
-            else {
-                $previous = undef;
-            }
         }
     }
     return $previous, $previous_index;
@@ -496,7 +500,8 @@ sub insert {
           . ( @lines == 1 ? ''  : 's' ) . ' ha'
           . ( @lines == 1 ? 's' : 've' )
           . ' been inserted by '
-          . __PACKAGE__ );
+          . __PACKAGE__
+          . ' rather than having been appended' );
     splice @{ $self->[IO] }, $index, 0, $comment, @lines;
 }
 
@@ -519,7 +524,7 @@ App::JobLog::Log - the code that lets us interact with the log
 
 =head1 VERSION
 
-version 1.002
+version 1.003
 
 =head1 DESCRIPTION
 
@@ -547,7 +552,8 @@ returning them as an array reference.
 
 C<validate> makes sure the log contains only valid lines, all events are 
 in chronological order, and every ending follows a beginning. Invalid lines
-are commented out and a warning is emitted.
+are commented out and a warning is emitted. The number of errors found is
+returned.
 
 =head2 first_event
 
